@@ -3,7 +3,19 @@ import path from "path"
 
 type FixtureData = {
     [filename: string]: {
-        options: { strict: boolean; ecmaVersion: 5 | 2015 | 2016 | 2017 | 2018 }
+        options: {
+            strict: boolean
+            ecmaVersion:
+                | 5
+                | 2015
+                | 2016
+                | 2017
+                | 2018
+                | 2019
+                | 2020
+                | 2021
+                | 2022
+        }
         patterns: {
             [source: string]:
                 | { ast: object }
